/****************************************************************************
** Meta object code from reading C++ file 'js_util_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../okular-23.08.5/core/script/js_util_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'js_util_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Okular__JSUtil_t {
    QByteArrayData data[14];
    char stringdata0[122];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Okular__JSUtil_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Okular__JSUtil_t qt_meta_stringdata_Okular__JSUtil = {
    {
QT_MOC_LITERAL(0, 0, 14), // "Okular::JSUtil"
QT_MOC_LITERAL(1, 15, 8), // "crackURL"
QT_MOC_LITERAL(2, 24, 8), // "QJSValue"
QT_MOC_LITERAL(3, 33, 0), // ""
QT_MOC_LITERAL(4, 34, 4), // "cURL"
QT_MOC_LITERAL(5, 39, 6), // "printd"
QT_MOC_LITERAL(6, 46, 7), // "oFormat"
QT_MOC_LITERAL(7, 54, 5), // "oDate"
QT_MOC_LITERAL(8, 60, 14), // "stringToNumber"
QT_MOC_LITERAL(9, 75, 6), // "number"
QT_MOC_LITERAL(10, 82, 14), // "numberToString"
QT_MOC_LITERAL(11, 97, 3), // "fmt"
QT_MOC_LITERAL(12, 101, 9), // "precision"
QT_MOC_LITERAL(13, 111, 10) // "localeName"

    },
    "Okular::JSUtil\0crackURL\0QJSValue\0\0"
    "cURL\0printd\0oFormat\0oDate\0stringToNumber\0"
    "number\0numberToString\0fmt\0precision\0"
    "localeName"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Okular__JSUtil[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // methods: name, argc, parameters, tag, flags
       1,    1,   49,    3, 0x02 /* Public */,
       5,    2,   52,    3, 0x02 /* Public */,
       8,    1,   57,    3, 0x02 /* Public */,
      10,    4,   60,    3, 0x02 /* Public */,
      10,    3,   69,    3, 0x22 /* Public | MethodCloned */,
      10,    2,   76,    3, 0x22 /* Public | MethodCloned */,
      10,    1,   81,    3, 0x22 /* Public | MethodCloned */,

 // methods: parameters
    0x80000000 | 2, QMetaType::QString,    4,
    0x80000000 | 2, 0x80000000 | 2, QMetaType::QDateTime,    6,    7,
    QMetaType::Double, QMetaType::QString,    9,
    QMetaType::QString, QMetaType::Double, QMetaType::QString, QMetaType::Int, QMetaType::QString,    9,   11,   12,   13,
    QMetaType::QString, QMetaType::Double, QMetaType::QString, QMetaType::Int,    9,   11,   12,
    QMetaType::QString, QMetaType::Double, QMetaType::QString,    9,   11,
    QMetaType::QString, QMetaType::Double,    9,

       0        // eod
};

void Okular::JSUtil::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<JSUtil *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { QJSValue _r = _t->crackURL((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 1: { QJSValue _r = _t->printd((*reinterpret_cast< const QJSValue(*)>(_a[1])),(*reinterpret_cast< const QDateTime(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 2: { double _r = _t->stringToNumber((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< double*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->numberToString((*reinterpret_cast< double(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->numberToString((*reinterpret_cast< double(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->numberToString((*reinterpret_cast< double(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->numberToString((*reinterpret_cast< double(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Okular::JSUtil::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Okular__JSUtil.data,
    qt_meta_data_Okular__JSUtil,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Okular::JSUtil::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Okular::JSUtil::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Okular__JSUtil.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Okular::JSUtil::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
