/****************************************************************************
** Meta object code from reading C++ file 'part.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../okular-23.08.5/part/part.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'part.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Okular__Part_t {
    QByteArrayData data[130];
    char stringdata0[1932];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Okular__Part_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Okular__Part_t qt_meta_stringdata_Okular__Part = {
    {
QT_MOC_LITERAL(0, 0, 12), // "Okular::Part"
QT_MOC_LITERAL(1, 13, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 29, 14), // "org.kde.okular"
QT_MOC_LITERAL(3, 44, 17), // "enablePrintAction"
QT_MOC_LITERAL(4, 62, 0), // ""
QT_MOC_LITERAL(5, 63, 6), // "enable"
QT_MOC_LITERAL(6, 70, 19), // "openSourceReference"
QT_MOC_LITERAL(7, 90, 11), // "absFileName"
QT_MOC_LITERAL(8, 102, 4), // "line"
QT_MOC_LITERAL(9, 107, 6), // "column"
QT_MOC_LITERAL(10, 114, 21), // "viewerMenuStateChange"
QT_MOC_LITERAL(11, 136, 7), // "enabled"
QT_MOC_LITERAL(12, 144, 17), // "enableCloseAction"
QT_MOC_LITERAL(13, 162, 15), // "mimeTypeChanged"
QT_MOC_LITERAL(14, 178, 9), // "QMimeType"
QT_MOC_LITERAL(15, 188, 8), // "mimeType"
QT_MOC_LITERAL(16, 197, 11), // "urlsDropped"
QT_MOC_LITERAL(17, 209, 11), // "QList<QUrl>"
QT_MOC_LITERAL(18, 221, 4), // "urls"
QT_MOC_LITERAL(19, 226, 15), // "fitWindowToPage"
QT_MOC_LITERAL(20, 242, 16), // "pageViewPortSize"
QT_MOC_LITERAL(21, 259, 8), // "pageSize"
QT_MOC_LITERAL(22, 268, 8), // "goToPage"
QT_MOC_LITERAL(23, 277, 9), // "Q_NOREPLY"
QT_MOC_LITERAL(24, 287, 4), // "page"
QT_MOC_LITERAL(25, 292, 12), // "openDocument"
QT_MOC_LITERAL(26, 305, 3), // "doc"
QT_MOC_LITERAL(27, 309, 5), // "pages"
QT_MOC_LITERAL(28, 315, 11), // "currentPage"
QT_MOC_LITERAL(29, 327, 15), // "currentDocument"
QT_MOC_LITERAL(30, 343, 16), // "documentMetaData"
QT_MOC_LITERAL(31, 360, 8), // "metaData"
QT_MOC_LITERAL(32, 369, 15), // "slotPreferences"
QT_MOC_LITERAL(33, 385, 8), // "slotFind"
QT_MOC_LITERAL(34, 394, 16), // "slotPrintPreview"
QT_MOC_LITERAL(35, 411, 16), // "slotPreviousPage"
QT_MOC_LITERAL(36, 428, 12), // "slotNextPage"
QT_MOC_LITERAL(37, 441, 13), // "slotGotoFirst"
QT_MOC_LITERAL(38, 455, 12), // "slotGotoLast"
QT_MOC_LITERAL(39, 468, 22), // "slotTogglePresentation"
QT_MOC_LITERAL(40, 491, 22), // "slotToggleChangeColors"
QT_MOC_LITERAL(41, 514, 19), // "slotSetChangeColors"
QT_MOC_LITERAL(42, 534, 6), // "active"
QT_MOC_LITERAL(43, 541, 6), // "reload"
QT_MOC_LITERAL(44, 548, 20), // "enableStartWithPrint"
QT_MOC_LITERAL(45, 569, 20), // "enableExitAfterPrint"
QT_MOC_LITERAL(46, 590, 19), // "enableStartWithFind"
QT_MOC_LITERAL(47, 610, 4), // "text"
QT_MOC_LITERAL(48, 615, 12), // "setEditorCmd"
QT_MOC_LITERAL(49, 628, 9), // "editorCmd"
QT_MOC_LITERAL(50, 638, 24), // "slotOpenContainingFolder"
QT_MOC_LITERAL(51, 663, 19), // "openUrlFromDocument"
QT_MOC_LITERAL(52, 683, 3), // "url"
QT_MOC_LITERAL(53, 687, 20), // "openUrlFromBookmarks"
QT_MOC_LITERAL(54, 708, 17), // "handleDroppedUrls"
QT_MOC_LITERAL(55, 726, 12), // "slotGoToPage"
QT_MOC_LITERAL(56, 739, 15), // "slotHistoryBack"
QT_MOC_LITERAL(57, 755, 15), // "slotHistoryNext"
QT_MOC_LITERAL(58, 771, 15), // "slotAddBookmark"
QT_MOC_LITERAL(59, 787, 26), // "slotRenameBookmarkFromMenu"
QT_MOC_LITERAL(60, 814, 26), // "slotRemoveBookmarkFromMenu"
QT_MOC_LITERAL(61, 841, 33), // "slotRenameCurrentViewportBook..."
QT_MOC_LITERAL(62, 875, 20), // "slotPreviousBookmark"
QT_MOC_LITERAL(63, 896, 16), // "slotNextBookmark"
QT_MOC_LITERAL(64, 913, 12), // "slotFindNext"
QT_MOC_LITERAL(65, 926, 12), // "slotFindPrev"
QT_MOC_LITERAL(66, 939, 14), // "slotSaveFileAs"
QT_MOC_LITERAL(67, 954, 32), // "showOkularArchiveAsDefaultFormat"
QT_MOC_LITERAL(68, 987, 13), // "slotNewConfig"
QT_MOC_LITERAL(69, 1001, 12), // "slotShowMenu"
QT_MOC_LITERAL(70, 1014, 19), // "const Okular::Page*"
QT_MOC_LITERAL(71, 1034, 5), // "point"
QT_MOC_LITERAL(72, 1040, 15), // "slotShowTOCMenu"
QT_MOC_LITERAL(73, 1056, 24), // "Okular::DocumentViewport"
QT_MOC_LITERAL(74, 1081, 2), // "vp"
QT_MOC_LITERAL(75, 1084, 5), // "title"
QT_MOC_LITERAL(76, 1090, 18), // "slotShowProperties"
QT_MOC_LITERAL(77, 1109, 21), // "slotShowEmbeddedFiles"
QT_MOC_LITERAL(78, 1131, 17), // "slotShowLeftPanel"
QT_MOC_LITERAL(79, 1149, 17), // "slotShowBottomBar"
QT_MOC_LITERAL(80, 1167, 20), // "slotShowPresentation"
QT_MOC_LITERAL(81, 1188, 20), // "slotHidePresentation"
QT_MOC_LITERAL(82, 1209, 23), // "slotUpdateHamburgerMenu"
QT_MOC_LITERAL(83, 1233, 12), // "slotExportAs"
QT_MOC_LITERAL(84, 1246, 8), // "QAction*"
QT_MOC_LITERAL(85, 1255, 16), // "slotImportPSFile"
QT_MOC_LITERAL(86, 1272, 16), // "slotAboutBackend"
QT_MOC_LITERAL(87, 1289, 10), // "slotReload"
QT_MOC_LITERAL(88, 1300, 5), // "close"
QT_MOC_LITERAL(89, 1306, 10), // "cannotQuit"
QT_MOC_LITERAL(90, 1317, 15), // "slotShowFindBar"
QT_MOC_LITERAL(91, 1333, 15), // "slotHideFindBar"
QT_MOC_LITERAL(92, 1349, 14), // "slotJobStarted"
QT_MOC_LITERAL(93, 1364, 9), // "KIO::Job*"
QT_MOC_LITERAL(94, 1374, 3), // "job"
QT_MOC_LITERAL(95, 1378, 15), // "slotJobFinished"
QT_MOC_LITERAL(96, 1394, 5), // "KJob*"
QT_MOC_LITERAL(97, 1400, 13), // "loadCancelled"
QT_MOC_LITERAL(98, 1414, 6), // "reason"
QT_MOC_LITERAL(99, 1421, 26), // "setWindowTitleFromDocument"
QT_MOC_LITERAL(100, 1448, 17), // "updateViewActions"
QT_MOC_LITERAL(101, 1466, 22), // "updateBookmarksActions"
QT_MOC_LITERAL(102, 1489, 9), // "enableTOC"
QT_MOC_LITERAL(103, 1499, 23), // "slotRebuildBookmarkMenu"
QT_MOC_LITERAL(104, 1523, 12), // "enableLayers"
QT_MOC_LITERAL(105, 1536, 27), // "enableSidebarSignaturesItem"
QT_MOC_LITERAL(106, 1564, 8), // "saveFile"
QT_MOC_LITERAL(107, 1573, 9), // "slotPrint"
QT_MOC_LITERAL(108, 1583, 13), // "slotFileDirty"
QT_MOC_LITERAL(109, 1597, 17), // "slotAttemptReload"
QT_MOC_LITERAL(110, 1615, 7), // "oneShot"
QT_MOC_LITERAL(111, 1623, 6), // "newUrl"
QT_MOC_LITERAL(112, 1630, 16), // "psTransformEnded"
QT_MOC_LITERAL(113, 1647, 20), // "QProcess::ExitStatus"
QT_MOC_LITERAL(114, 1668, 24), // "slotGeneratorPreferences"
QT_MOC_LITERAL(115, 1693, 14), // "KConfigDialog*"
QT_MOC_LITERAL(116, 1708, 12), // "errorMessage"
QT_MOC_LITERAL(117, 1721, 7), // "message"
QT_MOC_LITERAL(118, 1729, 8), // "duration"
QT_MOC_LITERAL(119, 1738, 14), // "warningMessage"
QT_MOC_LITERAL(120, 1753, 13), // "noticeMessage"
QT_MOC_LITERAL(121, 1767, 12), // "moveSplitter"
QT_MOC_LITERAL(122, 1780, 14), // "sideWidgetSize"
QT_MOC_LITERAL(123, 1795, 28), // "slotAccessibilityPreferences"
QT_MOC_LITERAL(124, 1824, 25), // "slotAnnotationPreferences"
QT_MOC_LITERAL(125, 1850, 34), // "slotHandleActivatedSourceRefe..."
QT_MOC_LITERAL(126, 1885, 3), // "col"
QT_MOC_LITERAL(127, 1889, 5), // "bool*"
QT_MOC_LITERAL(128, 1895, 7), // "handled"
QT_MOC_LITERAL(129, 1903, 28) // "activateTabIfAlreadyOpenFile"

    },
    "Okular::Part\0D-Bus Interface\0"
    "org.kde.okular\0enablePrintAction\0\0"
    "enable\0openSourceReference\0absFileName\0"
    "line\0column\0viewerMenuStateChange\0"
    "enabled\0enableCloseAction\0mimeTypeChanged\0"
    "QMimeType\0mimeType\0urlsDropped\0"
    "QList<QUrl>\0urls\0fitWindowToPage\0"
    "pageViewPortSize\0pageSize\0goToPage\0"
    "Q_NOREPLY\0page\0openDocument\0doc\0pages\0"
    "currentPage\0currentDocument\0"
    "documentMetaData\0metaData\0slotPreferences\0"
    "slotFind\0slotPrintPreview\0slotPreviousPage\0"
    "slotNextPage\0slotGotoFirst\0slotGotoLast\0"
    "slotTogglePresentation\0slotToggleChangeColors\0"
    "slotSetChangeColors\0active\0reload\0"
    "enableStartWithPrint\0enableExitAfterPrint\0"
    "enableStartWithFind\0text\0setEditorCmd\0"
    "editorCmd\0slotOpenContainingFolder\0"
    "openUrlFromDocument\0url\0openUrlFromBookmarks\0"
    "handleDroppedUrls\0slotGoToPage\0"
    "slotHistoryBack\0slotHistoryNext\0"
    "slotAddBookmark\0slotRenameBookmarkFromMenu\0"
    "slotRemoveBookmarkFromMenu\0"
    "slotRenameCurrentViewportBookmark\0"
    "slotPreviousBookmark\0slotNextBookmark\0"
    "slotFindNext\0slotFindPrev\0slotSaveFileAs\0"
    "showOkularArchiveAsDefaultFormat\0"
    "slotNewConfig\0slotShowMenu\0"
    "const Okular::Page*\0point\0slotShowTOCMenu\0"
    "Okular::DocumentViewport\0vp\0title\0"
    "slotShowProperties\0slotShowEmbeddedFiles\0"
    "slotShowLeftPanel\0slotShowBottomBar\0"
    "slotShowPresentation\0slotHidePresentation\0"
    "slotUpdateHamburgerMenu\0slotExportAs\0"
    "QAction*\0slotImportPSFile\0slotAboutBackend\0"
    "slotReload\0close\0cannotQuit\0slotShowFindBar\0"
    "slotHideFindBar\0slotJobStarted\0KIO::Job*\0"
    "job\0slotJobFinished\0KJob*\0loadCancelled\0"
    "reason\0setWindowTitleFromDocument\0"
    "updateViewActions\0updateBookmarksActions\0"
    "enableTOC\0slotRebuildBookmarkMenu\0"
    "enableLayers\0enableSidebarSignaturesItem\0"
    "saveFile\0slotPrint\0slotFileDirty\0"
    "slotAttemptReload\0oneShot\0newUrl\0"
    "psTransformEnded\0QProcess::ExitStatus\0"
    "slotGeneratorPreferences\0KConfigDialog*\0"
    "errorMessage\0message\0duration\0"
    "warningMessage\0noticeMessage\0moveSplitter\0"
    "sideWidgetSize\0slotAccessibilityPreferences\0"
    "slotAnnotationPreferences\0"
    "slotHandleActivatedSourceReference\0"
    "col\0bool*\0handled\0activateTabIfAlreadyOpenFile"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Okular__Part[] = {

 // content:
       8,       // revision
       0,       // classname
       1,   14, // classinfo
      92,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    1,  476,    4, 0x06 /* Public */,
       6,    3,  479,    4, 0x06 /* Public */,
      10,    1,  486,    4, 0x06 /* Public */,
      12,    1,  489,    4, 0x06 /* Public */,
      13,    1,  492,    4, 0x06 /* Public */,
      16,    1,  495,    4, 0x06 /* Public */,
      19,    2,  498,    4, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      22,    1,  503,   23, 0x4a /* Public | isScriptable */,
      25,    1,  506,   23, 0x4a /* Public | isScriptable */,
      27,    0,  509,    4, 0x4a /* Public | isScriptable */,
      28,    0,  510,    4, 0x4a /* Public | isScriptable */,
      29,    0,  511,    4, 0x4a /* Public | isScriptable */,
      30,    1,  512,    4, 0x4a /* Public | isScriptable */,
      32,    0,  515,    4, 0x4a /* Public | isScriptable */,
      33,    0,  516,    4, 0x4a /* Public | isScriptable */,
      34,    0,  517,    4, 0x4a /* Public | isScriptable */,
      35,    0,  518,    4, 0x4a /* Public | isScriptable */,
      36,    0,  519,    4, 0x4a /* Public | isScriptable */,
      37,    0,  520,    4, 0x4a /* Public | isScriptable */,
      38,    0,  521,    4, 0x4a /* Public | isScriptable */,
      39,    0,  522,    4, 0x4a /* Public | isScriptable */,
      40,    0,  523,    4, 0x4a /* Public | isScriptable */,
      41,    1,  524,    4, 0x4a /* Public | isScriptable */,
      43,    0,  527,   23, 0x4a /* Public | isScriptable */,
      44,    0,  528,   23, 0x4a /* Public | isScriptable */,
      45,    0,  529,   23, 0x4a /* Public | isScriptable */,
      46,    1,  530,   23, 0x4a /* Public | isScriptable */,
      48,    1,  533,   23, 0x4a /* Public | isScriptable */,
      50,    0,  536,    4, 0x4a /* Public | isScriptable */,
      51,    1,  537,    4, 0x09 /* Protected */,
      53,    1,  540,    4, 0x09 /* Protected */,
      54,    1,  543,    4, 0x09 /* Protected */,
      55,    0,  546,    4, 0x09 /* Protected */,
      56,    0,  547,    4, 0x09 /* Protected */,
      57,    0,  548,    4, 0x09 /* Protected */,
      58,    0,  549,    4, 0x09 /* Protected */,
      59,    0,  550,    4, 0x09 /* Protected */,
      60,    0,  551,    4, 0x09 /* Protected */,
      61,    0,  552,    4, 0x09 /* Protected */,
      62,    0,  553,    4, 0x09 /* Protected */,
      63,    0,  554,    4, 0x09 /* Protected */,
      64,    0,  555,    4, 0x09 /* Protected */,
      65,    0,  556,    4, 0x09 /* Protected */,
      66,    1,  557,    4, 0x09 /* Protected */,
      66,    0,  560,    4, 0x29 /* Protected | MethodCloned */,
      68,    0,  561,    4, 0x09 /* Protected */,
      69,    2,  562,    4, 0x09 /* Protected */,
      72,    3,  567,    4, 0x09 /* Protected */,
      76,    0,  574,    4, 0x09 /* Protected */,
      77,    0,  575,    4, 0x09 /* Protected */,
      78,    0,  576,    4, 0x09 /* Protected */,
      79,    0,  577,    4, 0x09 /* Protected */,
      80,    0,  578,    4, 0x09 /* Protected */,
      81,    0,  579,    4, 0x09 /* Protected */,
      82,    0,  580,    4, 0x09 /* Protected */,
      83,    1,  581,    4, 0x09 /* Protected */,
      85,    0,  584,    4, 0x09 /* Protected */,
      86,    0,  585,    4, 0x09 /* Protected */,
      87,    0,  586,    4, 0x09 /* Protected */,
      88,    0,  587,    4, 0x09 /* Protected */,
      89,    0,  588,    4, 0x09 /* Protected */,
      90,    0,  589,    4, 0x09 /* Protected */,
      91,    0,  590,    4, 0x09 /* Protected */,
      92,    1,  591,    4, 0x09 /* Protected */,
      95,    1,  594,    4, 0x09 /* Protected */,
      97,    1,  597,    4, 0x09 /* Protected */,
      99,    0,  600,    4, 0x09 /* Protected */,
     100,    0,  601,    4, 0x09 /* Protected */,
     101,    0,  602,    4, 0x09 /* Protected */,
     102,    1,  603,    4, 0x09 /* Protected */,
     103,    0,  606,    4, 0x09 /* Protected */,
     104,    1,  607,    4, 0x09 /* Protected */,
     105,    1,  610,    4, 0x09 /* Protected */,
     106,    0,  613,    4, 0x0a /* Public */,
     107,    0,  614,    4, 0x0a /* Public */,
     108,    1,  615,    4, 0x0a /* Public */,
     109,    2,  618,    4, 0x0a /* Public */,
     109,    1,  623,    4, 0x2a /* Public | MethodCloned */,
     109,    0,  626,    4, 0x2a /* Public | MethodCloned */,
     112,    2,  627,    4, 0x0a /* Public */,
     114,    0,  632,    4, 0x0a /* Public */,
     116,    2,  633,    4, 0x0a /* Public */,
     116,    1,  638,    4, 0x2a /* Public | MethodCloned */,
     119,    2,  641,    4, 0x0a /* Public */,
     119,    1,  646,    4, 0x2a /* Public | MethodCloned */,
     120,    2,  649,    4, 0x0a /* Public */,
     120,    1,  654,    4, 0x2a /* Public | MethodCloned */,
     121,    1,  657,    4, 0x0a /* Public */,
     123,    0,  660,    4, 0x08 /* Private */,
     124,    0,  661,    4, 0x08 /* Private */,
     125,    4,  662,    4, 0x08 /* Private */,

 // methods: name, argc, parameters, tag, flags
     129,    0,  671,    4, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, QMetaType::QString, QMetaType::Int, QMetaType::Int,    7,    8,    9,
    QMetaType::Void, QMetaType::Bool,   11,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void, QMetaType::QSize, QMetaType::QSize,   20,   21,

 // slots: parameters
    QMetaType::Void, QMetaType::UInt,   24,
    QMetaType::Void, QMetaType::QString,   26,
    QMetaType::UInt,
    QMetaType::UInt,
    QMetaType::QString,
    QMetaType::QString, QMetaType::QString,   31,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   42,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   47,
    QMetaType::Void, QMetaType::QString,   49,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QUrl,   52,
    QMetaType::Void, QMetaType::QUrl,   52,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Bool, QMetaType::Bool,   67,
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 70, QMetaType::QPoint,   24,   71,
    QMetaType::Void, 0x80000000 | 73, QMetaType::QPoint, QMetaType::QString,   74,   71,   75,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 84,    4,
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 93,   94,
    QMetaType::Void, 0x80000000 | 96,   94,
    QMetaType::Void, QMetaType::QString,   98,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Bool, QMetaType::Bool, QMetaType::QUrl,  110,  111,
    QMetaType::Bool, QMetaType::Bool,  110,
    QMetaType::Bool,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 113,    4,    4,
    0x80000000 | 115,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,  117,  118,
    QMetaType::Void, QMetaType::QString,  117,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,  117,  118,
    QMetaType::Void, QMetaType::QString,  117,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,  117,  118,
    QMetaType::Void, QMetaType::QString,  117,
    QMetaType::Void, QMetaType::Int,  122,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::Int, QMetaType::Int, 0x80000000 | 127,    7,    8,  126,  128,

 // methods: parameters
    QMetaType::Bool,

       0        // eod
};

void Okular::Part::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Part *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->enablePrintAction((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->openSourceReference((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 2: _t->viewerMenuStateChange((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->enableCloseAction((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->mimeTypeChanged((*reinterpret_cast< const QMimeType(*)>(_a[1]))); break;
        case 5: _t->urlsDropped((*reinterpret_cast< const QList<QUrl>(*)>(_a[1]))); break;
        case 6: _t->fitWindowToPage((*reinterpret_cast< const QSize(*)>(_a[1])),(*reinterpret_cast< const QSize(*)>(_a[2]))); break;
        case 7: _t->goToPage((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 8: _t->openDocument((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: { uint _r = _t->pages();
            if (_a[0]) *reinterpret_cast< uint*>(_a[0]) = std::move(_r); }  break;
        case 10: { uint _r = _t->currentPage();
            if (_a[0]) *reinterpret_cast< uint*>(_a[0]) = std::move(_r); }  break;
        case 11: { QString _r = _t->currentDocument();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { QString _r = _t->documentMetaData((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->slotPreferences(); break;
        case 14: _t->slotFind(); break;
        case 15: _t->slotPrintPreview(); break;
        case 16: _t->slotPreviousPage(); break;
        case 17: _t->slotNextPage(); break;
        case 18: _t->slotGotoFirst(); break;
        case 19: _t->slotGotoLast(); break;
        case 20: _t->slotTogglePresentation(); break;
        case 21: _t->slotToggleChangeColors(); break;
        case 22: _t->slotSetChangeColors((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 23: _t->reload(); break;
        case 24: _t->enableStartWithPrint(); break;
        case 25: _t->enableExitAfterPrint(); break;
        case 26: _t->enableStartWithFind((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 27: _t->setEditorCmd((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 28: _t->slotOpenContainingFolder(); break;
        case 29: _t->openUrlFromDocument((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 30: _t->openUrlFromBookmarks((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 31: _t->handleDroppedUrls((*reinterpret_cast< const QList<QUrl>(*)>(_a[1]))); break;
        case 32: _t->slotGoToPage(); break;
        case 33: _t->slotHistoryBack(); break;
        case 34: _t->slotHistoryNext(); break;
        case 35: _t->slotAddBookmark(); break;
        case 36: _t->slotRenameBookmarkFromMenu(); break;
        case 37: _t->slotRemoveBookmarkFromMenu(); break;
        case 38: _t->slotRenameCurrentViewportBookmark(); break;
        case 39: _t->slotPreviousBookmark(); break;
        case 40: _t->slotNextBookmark(); break;
        case 41: _t->slotFindNext(); break;
        case 42: _t->slotFindPrev(); break;
        case 43: { bool _r = _t->slotSaveFileAs((*reinterpret_cast< bool(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 44: { bool _r = _t->slotSaveFileAs();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 45: _t->slotNewConfig(); break;
        case 46: _t->slotShowMenu((*reinterpret_cast< const Okular::Page*(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2]))); break;
        case 47: _t->slotShowTOCMenu((*reinterpret_cast< const Okular::DocumentViewport(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 48: _t->slotShowProperties(); break;
        case 49: _t->slotShowEmbeddedFiles(); break;
        case 50: _t->slotShowLeftPanel(); break;
        case 51: _t->slotShowBottomBar(); break;
        case 52: _t->slotShowPresentation(); break;
        case 53: _t->slotHidePresentation(); break;
        case 54: _t->slotUpdateHamburgerMenu(); break;
        case 55: _t->slotExportAs((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 56: { bool _r = _t->slotImportPSFile();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 57: _t->slotAboutBackend(); break;
        case 58: _t->slotReload(); break;
        case 59: _t->close(); break;
        case 60: _t->cannotQuit(); break;
        case 61: _t->slotShowFindBar(); break;
        case 62: _t->slotHideFindBar(); break;
        case 63: _t->slotJobStarted((*reinterpret_cast< KIO::Job*(*)>(_a[1]))); break;
        case 64: _t->slotJobFinished((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 65: _t->loadCancelled((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 66: _t->setWindowTitleFromDocument(); break;
        case 67: _t->updateViewActions(); break;
        case 68: _t->updateBookmarksActions(); break;
        case 69: _t->enableTOC((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 70: _t->slotRebuildBookmarkMenu(); break;
        case 71: _t->enableLayers((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 72: _t->enableSidebarSignaturesItem((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 73: { bool _r = _t->saveFile();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 74: _t->slotPrint(); break;
        case 75: _t->slotFileDirty((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 76: { bool _r = _t->slotAttemptReload((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< const QUrl(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 77: { bool _r = _t->slotAttemptReload((*reinterpret_cast< bool(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 78: { bool _r = _t->slotAttemptReload();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 79: _t->psTransformEnded((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QProcess::ExitStatus(*)>(_a[2]))); break;
        case 80: { KConfigDialog* _r = _t->slotGeneratorPreferences();
            if (_a[0]) *reinterpret_cast< KConfigDialog**>(_a[0]) = std::move(_r); }  break;
        case 81: _t->errorMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 82: _t->errorMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 83: _t->warningMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 84: _t->warningMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 85: _t->noticeMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 86: _t->noticeMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 87: _t->moveSplitter((*reinterpret_cast< const int(*)>(_a[1]))); break;
        case 88: _t->slotAccessibilityPreferences(); break;
        case 89: _t->slotAnnotationPreferences(); break;
        case 90: _t->slotHandleActivatedSourceReference((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< bool*(*)>(_a[4]))); break;
        case 91: { bool _r = _t->activateTabIfAlreadyOpenFile();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
            }
            break;
        case 63:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KIO::Job* >(); break;
            }
            break;
        case 64:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Part::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Part::enablePrintAction)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Part::*)(const QString & , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Part::openSourceReference)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Part::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Part::viewerMenuStateChange)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (Part::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Part::enableCloseAction)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (Part::*)(const QMimeType & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Part::mimeTypeChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (Part::*)(const QList<QUrl> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Part::urlsDropped)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (Part::*)(const QSize , const QSize );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Part::fitWindowToPage)) {
                *result = 6;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Okular::Part::staticMetaObject = { {
    QMetaObject::SuperData::link<KParts::ReadWritePart::staticMetaObject>(),
    qt_meta_stringdata_Okular__Part.data,
    qt_meta_data_Okular__Part,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Okular::Part::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Okular::Part::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Okular__Part.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Okular::DocumentObserver"))
        return static_cast< Okular::DocumentObserver*>(this);
    if (!strcmp(_clname, "KDocumentViewer"))
        return static_cast< KDocumentViewer*>(this);
    if (!strcmp(_clname, "Okular::ViewerInterface"))
        return static_cast< Okular::ViewerInterface*>(this);
    if (!strcmp(_clname, "org.kde.kdocumentviewer/0.1"))
        return static_cast< KDocumentViewer*>(this);
    if (!strcmp(_clname, "org.kde.okular.ViewerInterface/0.1"))
        return static_cast< Okular::ViewerInterface*>(this);
    return KParts::ReadWritePart::qt_metacast(_clname);
}

int Okular::Part::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::ReadWritePart::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 92)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 92;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 92)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 92;
    }
    return _id;
}

// SIGNAL 0
void Okular::Part::enablePrintAction(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Okular::Part::openSourceReference(const QString & _t1, int _t2, int _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Okular::Part::viewerMenuStateChange(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Okular::Part::enableCloseAction(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Okular::Part::mimeTypeChanged(const QMimeType & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Okular::Part::urlsDropped(const QList<QUrl> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Okular::Part::fitWindowToPage(const QSize _t1, const QSize _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
