/****************************************************************************
** Meta object code from reading C++ file 'js_document_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../okular-23.08.5/core/script/js_document_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'js_document_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Okular__JSDocument_t {
    QByteArrayData data[30];
    char stringdata0[289];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Okular__JSDocument_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Okular__JSDocument_t qt_meta_stringdata_Okular__JSDocument = {
    {
QT_MOC_LITERAL(0, 0, 18), // "Okular::JSDocument"
QT_MOC_LITERAL(1, 19, 8), // "getField"
QT_MOC_LITERAL(2, 28, 8), // "QJSValue"
QT_MOC_LITERAL(3, 37, 0), // ""
QT_MOC_LITERAL(4, 38, 5), // "cName"
QT_MOC_LITERAL(5, 44, 12), // "getPageLabel"
QT_MOC_LITERAL(6, 57, 5), // "nPage"
QT_MOC_LITERAL(7, 63, 15), // "getPageRotation"
QT_MOC_LITERAL(8, 79, 13), // "gotoNamedDest"
QT_MOC_LITERAL(9, 93, 13), // "syncAnnotScan"
QT_MOC_LITERAL(10, 107, 15), // "getNthFieldName"
QT_MOC_LITERAL(11, 123, 6), // "nIndex"
QT_MOC_LITERAL(12, 130, 7), // "getOCGs"
QT_MOC_LITERAL(13, 138, 8), // "numPages"
QT_MOC_LITERAL(14, 147, 7), // "pageNum"
QT_MOC_LITERAL(15, 155, 16), // "documentFileName"
QT_MOC_LITERAL(16, 172, 8), // "filesize"
QT_MOC_LITERAL(17, 181, 4), // "path"
QT_MOC_LITERAL(18, 186, 3), // "URL"
QT_MOC_LITERAL(19, 190, 15), // "permStatusReady"
QT_MOC_LITERAL(20, 206, 11), // "dataObjects"
QT_MOC_LITERAL(21, 218, 8), // "external"
QT_MOC_LITERAL(22, 227, 9), // "numFields"
QT_MOC_LITERAL(23, 237, 4), // "info"
QT_MOC_LITERAL(24, 242, 6), // "author"
QT_MOC_LITERAL(25, 249, 7), // "creator"
QT_MOC_LITERAL(26, 257, 8), // "keywords"
QT_MOC_LITERAL(27, 266, 8), // "producer"
QT_MOC_LITERAL(28, 275, 5), // "title"
QT_MOC_LITERAL(29, 281, 7) // "subject"

    },
    "Okular::JSDocument\0getField\0QJSValue\0"
    "\0cName\0getPageLabel\0nPage\0getPageRotation\0"
    "gotoNamedDest\0syncAnnotScan\0getNthFieldName\0"
    "nIndex\0getOCGs\0numPages\0pageNum\0"
    "documentFileName\0filesize\0path\0URL\0"
    "permStatusReady\0dataObjects\0external\0"
    "numFields\0info\0author\0creator\0keywords\0"
    "producer\0title\0subject"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Okular__JSDocument[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
      17,   74, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // methods: name, argc, parameters, tag, flags
       1,    1,   54,    3, 0x02 /* Public */,
       5,    1,   57,    3, 0x02 /* Public */,
       7,    1,   60,    3, 0x02 /* Public */,
       8,    1,   63,    3, 0x02 /* Public */,
       9,    0,   66,    3, 0x02 /* Public */,
      10,    1,   67,    3, 0x02 /* Public */,
      12,    1,   70,    3, 0x02 /* Public */,
      12,    0,   73,    3, 0x22 /* Public | MethodCloned */,

 // methods: parameters
    0x80000000 | 2, QMetaType::QString,    4,
    QMetaType::QString, QMetaType::Int,    6,
    QMetaType::Int, QMetaType::Int,    6,
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void,
    0x80000000 | 2, QMetaType::Int,   11,
    0x80000000 | 2, QMetaType::Int,    6,
    0x80000000 | 2,

 // properties: name, type, flags
      13, QMetaType::Int, 0x00095401,
      14, QMetaType::Int, 0x00095103,
      15, QMetaType::QString, 0x00095401,
      16, QMetaType::Int, 0x00095401,
      17, QMetaType::QString, 0x00095401,
      18, QMetaType::QString, 0x00095401,
      19, QMetaType::Bool, 0x00095401,
      20, 0x80000000 | 2, 0x00095409,
      21, QMetaType::Bool, 0x00095401,
      22, QMetaType::Int, 0x00095401,
      23, 0x80000000 | 2, 0x00095409,
      24, QMetaType::QString, 0x00095401,
      25, QMetaType::QString, 0x00095401,
      26, QMetaType::QString, 0x00095401,
      27, QMetaType::QString, 0x00095401,
      28, QMetaType::QString, 0x00095401,
      29, QMetaType::QString, 0x00095401,

       0        // eod
};

void Okular::JSDocument::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<JSDocument *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { QJSValue _r = _t->getField((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->getPageLabel((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { int _r = _t->getPageRotation((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->gotoNamedDest((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->syncAnnotScan(); break;
        case 5: { QJSValue _r = _t->getNthFieldName((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 6: { QJSValue _r = _t->getOCGs((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 7: { QJSValue _r = _t->getOCGs();
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 10:
        case 7:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<JSDocument *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< int*>(_v) = _t->numPages(); break;
        case 1: *reinterpret_cast< int*>(_v) = _t->pageNum(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->documentFileName(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->filesize(); break;
        case 4: *reinterpret_cast< QString*>(_v) = _t->path(); break;
        case 5: *reinterpret_cast< QString*>(_v) = _t->URL(); break;
        case 6: *reinterpret_cast< bool*>(_v) = _t->permStatusReady(); break;
        case 7: *reinterpret_cast< QJSValue*>(_v) = _t->dataObjects(); break;
        case 8: *reinterpret_cast< bool*>(_v) = _t->external(); break;
        case 9: *reinterpret_cast< int*>(_v) = _t->numFields(); break;
        case 10: *reinterpret_cast< QJSValue*>(_v) = _t->info(); break;
        case 11: *reinterpret_cast< QString*>(_v) = _t->author(); break;
        case 12: *reinterpret_cast< QString*>(_v) = _t->creator(); break;
        case 13: *reinterpret_cast< QString*>(_v) = _t->keywords(); break;
        case 14: *reinterpret_cast< QString*>(_v) = _t->producer(); break;
        case 15: *reinterpret_cast< QString*>(_v) = _t->title(); break;
        case 16: *reinterpret_cast< QString*>(_v) = _t->subject(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<JSDocument *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setPageNum(*reinterpret_cast< int*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Okular::JSDocument::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Okular__JSDocument.data,
    qt_meta_data_Okular__JSDocument,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Okular::JSDocument::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Okular::JSDocument::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Okular__JSDocument.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Okular::JSDocument::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 17;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 17;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 17;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 17;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 17;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
