/****************************************************************************
** Meta object code from reading C++ file 'formwidgets.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../okular-23.08.5/part/formwidgets.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'formwidgets.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_FormWidgetsController_t {
    QByteArrayData data[44];
    char stringdata0[688];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_FormWidgetsController_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_FormWidgetsController_t qt_meta_stringdata_FormWidgetsController = {
    {
QT_MOC_LITERAL(0, 0, 21), // "FormWidgetsController"
QT_MOC_LITERAL(1, 22, 7), // "changed"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 10), // "pageNumber"
QT_MOC_LITERAL(4, 42, 11), // "requestUndo"
QT_MOC_LITERAL(5, 54, 11), // "requestRedo"
QT_MOC_LITERAL(6, 66, 14), // "canUndoChanged"
QT_MOC_LITERAL(7, 81, 13), // "undoAvailable"
QT_MOC_LITERAL(8, 95, 14), // "canRedoChanged"
QT_MOC_LITERAL(9, 110, 13), // "redoAvailable"
QT_MOC_LITERAL(10, 124, 23), // "formTextChangedByWidget"
QT_MOC_LITERAL(11, 148, 22), // "Okular::FormFieldText*"
QT_MOC_LITERAL(12, 171, 4), // "form"
QT_MOC_LITERAL(13, 176, 11), // "newContents"
QT_MOC_LITERAL(14, 188, 12), // "newCursorPos"
QT_MOC_LITERAL(15, 201, 13), // "prevCursorPos"
QT_MOC_LITERAL(16, 215, 13), // "prevAnchorPos"
QT_MOC_LITERAL(17, 229, 25), // "formTextChangedByUndoRedo"
QT_MOC_LITERAL(18, 255, 8), // "contents"
QT_MOC_LITERAL(19, 264, 9), // "cursorPos"
QT_MOC_LITERAL(20, 274, 9), // "anchorPos"
QT_MOC_LITERAL(21, 284, 23), // "formListChangedByWidget"
QT_MOC_LITERAL(22, 308, 24), // "Okular::FormFieldChoice*"
QT_MOC_LITERAL(23, 333, 10), // "QList<int>"
QT_MOC_LITERAL(24, 344, 10), // "newChoices"
QT_MOC_LITERAL(25, 355, 25), // "formListChangedByUndoRedo"
QT_MOC_LITERAL(26, 381, 7), // "choices"
QT_MOC_LITERAL(27, 389, 24), // "formComboChangedByWidget"
QT_MOC_LITERAL(28, 414, 7), // "newText"
QT_MOC_LITERAL(29, 422, 26), // "formComboChangedByUndoRedo"
QT_MOC_LITERAL(30, 449, 4), // "text"
QT_MOC_LITERAL(31, 454, 26), // "formButtonsChangedByWidget"
QT_MOC_LITERAL(32, 481, 31), // "QList<Okular::FormFieldButton*>"
QT_MOC_LITERAL(33, 513, 11), // "formButtons"
QT_MOC_LITERAL(34, 525, 11), // "QList<bool>"
QT_MOC_LITERAL(35, 537, 15), // "newButtonStates"
QT_MOC_LITERAL(36, 553, 6), // "action"
QT_MOC_LITERAL(37, 560, 15), // "Okular::Action*"
QT_MOC_LITERAL(38, 576, 17), // "refreshFormWidget"
QT_MOC_LITERAL(39, 594, 18), // "Okular::FormField*"
QT_MOC_LITERAL(40, 613, 17), // "slotButtonClicked"
QT_MOC_LITERAL(41, 631, 16), // "QAbstractButton*"
QT_MOC_LITERAL(42, 648, 6), // "button"
QT_MOC_LITERAL(43, 655, 32) // "slotFormButtonsChangedByUndoRedo"

    },
    "FormWidgetsController\0changed\0\0"
    "pageNumber\0requestUndo\0requestRedo\0"
    "canUndoChanged\0undoAvailable\0"
    "canRedoChanged\0redoAvailable\0"
    "formTextChangedByWidget\0Okular::FormFieldText*\0"
    "form\0newContents\0newCursorPos\0"
    "prevCursorPos\0prevAnchorPos\0"
    "formTextChangedByUndoRedo\0contents\0"
    "cursorPos\0anchorPos\0formListChangedByWidget\0"
    "Okular::FormFieldChoice*\0QList<int>\0"
    "newChoices\0formListChangedByUndoRedo\0"
    "choices\0formComboChangedByWidget\0"
    "newText\0formComboChangedByUndoRedo\0"
    "text\0formButtonsChangedByWidget\0"
    "QList<Okular::FormFieldButton*>\0"
    "formButtons\0QList<bool>\0newButtonStates\0"
    "action\0Okular::Action*\0refreshFormWidget\0"
    "Okular::FormField*\0slotButtonClicked\0"
    "QAbstractButton*\0button\0"
    "slotFormButtonsChangedByUndoRedo"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_FormWidgetsController[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      16,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      14,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   94,    2, 0x06 /* Public */,
       4,    0,   97,    2, 0x06 /* Public */,
       5,    0,   98,    2, 0x06 /* Public */,
       6,    1,   99,    2, 0x06 /* Public */,
       8,    1,  102,    2, 0x06 /* Public */,
      10,    6,  105,    2, 0x06 /* Public */,
      17,    5,  118,    2, 0x06 /* Public */,
      21,    3,  129,    2, 0x06 /* Public */,
      25,    3,  136,    2, 0x06 /* Public */,
      27,    6,  143,    2, 0x06 /* Public */,
      29,    5,  156,    2, 0x06 /* Public */,
      31,    3,  167,    2, 0x06 /* Public */,
      36,    1,  174,    2, 0x06 /* Public */,
      38,    1,  177,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      40,    1,  180,    2, 0x08 /* Private */,
      43,    2,  183,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 11, QMetaType::QString, QMetaType::Int, QMetaType::Int, QMetaType::Int,    3,   12,   13,   14,   15,   16,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 11, QMetaType::QString, QMetaType::Int, QMetaType::Int,    3,   12,   18,   19,   20,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 22, 0x80000000 | 23,    3,   12,   24,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 22, 0x80000000 | 23,    3,   12,   26,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 22, QMetaType::QString, QMetaType::Int, QMetaType::Int, QMetaType::Int,    3,   12,   28,   14,   15,   16,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 22, QMetaType::QString, QMetaType::Int, QMetaType::Int,    3,   12,   30,   19,   20,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 32, 0x80000000 | 34,    3,   33,   35,
    QMetaType::Void, 0x80000000 | 37,   36,
    QMetaType::Void, 0x80000000 | 39,   12,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 41,   42,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 32,    3,   33,

       0        // eod
};

void FormWidgetsController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<FormWidgetsController *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->changed((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->requestUndo(); break;
        case 2: _t->requestRedo(); break;
        case 3: _t->canUndoChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->canRedoChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->formTextChangedByWidget((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< Okular::FormFieldText*(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6]))); break;
        case 6: _t->formTextChangedByUndoRedo((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< Okular::FormFieldText*(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5]))); break;
        case 7: _t->formListChangedByWidget((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< Okular::FormFieldChoice*(*)>(_a[2])),(*reinterpret_cast< const QList<int>(*)>(_a[3]))); break;
        case 8: _t->formListChangedByUndoRedo((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< Okular::FormFieldChoice*(*)>(_a[2])),(*reinterpret_cast< const QList<int>(*)>(_a[3]))); break;
        case 9: _t->formComboChangedByWidget((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< Okular::FormFieldChoice*(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6]))); break;
        case 10: _t->formComboChangedByUndoRedo((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< Okular::FormFieldChoice*(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5]))); break;
        case 11: _t->formButtonsChangedByWidget((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QList<Okular::FormFieldButton*>(*)>(_a[2])),(*reinterpret_cast< const QList<bool>(*)>(_a[3]))); break;
        case 12: _t->action((*reinterpret_cast< Okular::Action*(*)>(_a[1]))); break;
        case 13: _t->refreshFormWidget((*reinterpret_cast< Okular::FormField*(*)>(_a[1]))); break;
        case 14: _t->slotButtonClicked((*reinterpret_cast< QAbstractButton*(*)>(_a[1]))); break;
        case 15: _t->slotFormButtonsChangedByUndoRedo((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QList<Okular::FormFieldButton*>(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 2:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<int> >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 2:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<int> >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 2:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<bool> >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractButton* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (FormWidgetsController::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FormWidgetsController::changed)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (FormWidgetsController::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FormWidgetsController::requestUndo)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (FormWidgetsController::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FormWidgetsController::requestRedo)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (FormWidgetsController::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FormWidgetsController::canUndoChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (FormWidgetsController::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FormWidgetsController::canRedoChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (FormWidgetsController::*)(int , Okular::FormFieldText * , const QString & , int , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FormWidgetsController::formTextChangedByWidget)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (FormWidgetsController::*)(int , Okular::FormFieldText * , const QString & , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FormWidgetsController::formTextChangedByUndoRedo)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (FormWidgetsController::*)(int , Okular::FormFieldChoice * , const QList<int> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FormWidgetsController::formListChangedByWidget)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (FormWidgetsController::*)(int , Okular::FormFieldChoice * , const QList<int> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FormWidgetsController::formListChangedByUndoRedo)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (FormWidgetsController::*)(int , Okular::FormFieldChoice * , const QString & , int , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FormWidgetsController::formComboChangedByWidget)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (FormWidgetsController::*)(int , Okular::FormFieldChoice * , const QString & , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FormWidgetsController::formComboChangedByUndoRedo)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (FormWidgetsController::*)(int , const QList<Okular::FormFieldButton*> & , const QList<bool> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FormWidgetsController::formButtonsChangedByWidget)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (FormWidgetsController::*)(Okular::Action * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FormWidgetsController::action)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (FormWidgetsController::*)(Okular::FormField * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FormWidgetsController::refreshFormWidget)) {
                *result = 13;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject FormWidgetsController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_FormWidgetsController.data,
    qt_meta_data_FormWidgetsController,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *FormWidgetsController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FormWidgetsController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_FormWidgetsController.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int FormWidgetsController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void FormWidgetsController::changed(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void FormWidgetsController::requestUndo()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void FormWidgetsController::requestRedo()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void FormWidgetsController::canUndoChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void FormWidgetsController::canRedoChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void FormWidgetsController::formTextChangedByWidget(int _t1, Okular::FormFieldText * _t2, const QString & _t3, int _t4, int _t5, int _t6)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t5))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t6))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void FormWidgetsController::formTextChangedByUndoRedo(int _t1, Okular::FormFieldText * _t2, const QString & _t3, int _t4, int _t5)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t5))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void FormWidgetsController::formListChangedByWidget(int _t1, Okular::FormFieldChoice * _t2, const QList<int> & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void FormWidgetsController::formListChangedByUndoRedo(int _t1, Okular::FormFieldChoice * _t2, const QList<int> & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void FormWidgetsController::formComboChangedByWidget(int _t1, Okular::FormFieldChoice * _t2, const QString & _t3, int _t4, int _t5, int _t6)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t5))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t6))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void FormWidgetsController::formComboChangedByUndoRedo(int _t1, Okular::FormFieldChoice * _t2, const QString & _t3, int _t4, int _t5)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t5))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void FormWidgetsController::formButtonsChangedByWidget(int _t1, const QList<Okular::FormFieldButton*> & _t2, const QList<bool> & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void FormWidgetsController::action(Okular::Action * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void FormWidgetsController::refreshFormWidget(Okular::FormField * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}
struct qt_meta_stringdata_PushButtonEdit_t {
    QByteArrayData data[1];
    char stringdata0[15];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PushButtonEdit_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PushButtonEdit_t qt_meta_stringdata_PushButtonEdit = {
    {
QT_MOC_LITERAL(0, 0, 14) // "PushButtonEdit"

    },
    "PushButtonEdit"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PushButtonEdit[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void PushButtonEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject PushButtonEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<QPushButton::staticMetaObject>(),
    qt_meta_stringdata_PushButtonEdit.data,
    qt_meta_data_PushButtonEdit,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *PushButtonEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PushButtonEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_PushButtonEdit.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "FormWidgetIface"))
        return static_cast< FormWidgetIface*>(this);
    return QPushButton::qt_metacast(_clname);
}

int PushButtonEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QPushButton::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_CheckBoxEdit_t {
    QByteArrayData data[1];
    char stringdata0[13];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CheckBoxEdit_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CheckBoxEdit_t qt_meta_stringdata_CheckBoxEdit = {
    {
QT_MOC_LITERAL(0, 0, 12) // "CheckBoxEdit"

    },
    "CheckBoxEdit"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CheckBoxEdit[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void CheckBoxEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject CheckBoxEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<QCheckBox::staticMetaObject>(),
    qt_meta_stringdata_CheckBoxEdit.data,
    qt_meta_data_CheckBoxEdit,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CheckBoxEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CheckBoxEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CheckBoxEdit.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "FormWidgetIface"))
        return static_cast< FormWidgetIface*>(this);
    return QCheckBox::qt_metacast(_clname);
}

int CheckBoxEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QCheckBox::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_RadioButtonEdit_t {
    QByteArrayData data[1];
    char stringdata0[16];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_RadioButtonEdit_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_RadioButtonEdit_t qt_meta_stringdata_RadioButtonEdit = {
    {
QT_MOC_LITERAL(0, 0, 15) // "RadioButtonEdit"

    },
    "RadioButtonEdit"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_RadioButtonEdit[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void RadioButtonEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject RadioButtonEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<QRadioButton::staticMetaObject>(),
    qt_meta_stringdata_RadioButtonEdit.data,
    qt_meta_data_RadioButtonEdit,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *RadioButtonEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RadioButtonEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_RadioButtonEdit.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "FormWidgetIface"))
        return static_cast< FormWidgetIface*>(this);
    return QRadioButton::qt_metacast(_clname);
}

int RadioButtonEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QRadioButton::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_FormLineEdit_t {
    QByteArrayData data[10];
    char stringdata0[130];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_FormLineEdit_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_FormLineEdit_t qt_meta_stringdata_FormLineEdit = {
    {
QT_MOC_LITERAL(0, 0, 12), // "FormLineEdit"
QT_MOC_LITERAL(1, 13, 31), // "slotHandleTextChangedByUndoRedo"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 10), // "pageNumber"
QT_MOC_LITERAL(4, 57, 22), // "Okular::FormFieldText*"
QT_MOC_LITERAL(5, 80, 8), // "textForm"
QT_MOC_LITERAL(6, 89, 8), // "contents"
QT_MOC_LITERAL(7, 98, 9), // "cursorPos"
QT_MOC_LITERAL(8, 108, 9), // "anchorPos"
QT_MOC_LITERAL(9, 118, 11) // "slotChanged"

    },
    "FormLineEdit\0slotHandleTextChangedByUndoRedo\0"
    "\0pageNumber\0Okular::FormFieldText*\0"
    "textForm\0contents\0cursorPos\0anchorPos\0"
    "slotChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_FormLineEdit[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    5,   24,    2, 0x0a /* Public */,
       9,    0,   35,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int, 0x80000000 | 4, QMetaType::QString, QMetaType::Int, QMetaType::Int,    3,    5,    6,    7,    8,
    QMetaType::Void,

       0        // eod
};

void FormLineEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<FormLineEdit *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->slotHandleTextChangedByUndoRedo((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< Okular::FormFieldText*(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5]))); break;
        case 1: _t->slotChanged(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject FormLineEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<QLineEdit::staticMetaObject>(),
    qt_meta_stringdata_FormLineEdit.data,
    qt_meta_data_FormLineEdit,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *FormLineEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FormLineEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_FormLineEdit.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "FormWidgetIface"))
        return static_cast< FormWidgetIface*>(this);
    return QLineEdit::qt_metacast(_clname);
}

int FormLineEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QLineEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
struct qt_meta_stringdata_TextAreaEdit_t {
    QByteArrayData data[13];
    char stringdata0[177];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_TextAreaEdit_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_TextAreaEdit_t qt_meta_stringdata_TextAreaEdit = {
    {
QT_MOC_LITERAL(0, 0, 12), // "TextAreaEdit"
QT_MOC_LITERAL(1, 13, 31), // "slotHandleTextChangedByUndoRedo"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 10), // "pageNumber"
QT_MOC_LITERAL(4, 57, 22), // "Okular::FormFieldText*"
QT_MOC_LITERAL(5, 80, 8), // "textForm"
QT_MOC_LITERAL(6, 89, 8), // "contents"
QT_MOC_LITERAL(7, 98, 9), // "cursorPos"
QT_MOC_LITERAL(8, 108, 9), // "anchorPos"
QT_MOC_LITERAL(9, 118, 34), // "slotUpdateUndoAndRedoInContex..."
QT_MOC_LITERAL(10, 153, 6), // "QMenu*"
QT_MOC_LITERAL(11, 160, 4), // "menu"
QT_MOC_LITERAL(12, 165, 11) // "slotChanged"

    },
    "TextAreaEdit\0slotHandleTextChangedByUndoRedo\0"
    "\0pageNumber\0Okular::FormFieldText*\0"
    "textForm\0contents\0cursorPos\0anchorPos\0"
    "slotUpdateUndoAndRedoInContextMenu\0"
    "QMenu*\0menu\0slotChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_TextAreaEdit[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    5,   29,    2, 0x0a /* Public */,
       9,    1,   40,    2, 0x0a /* Public */,
      12,    0,   43,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int, 0x80000000 | 4, QMetaType::QString, QMetaType::Int, QMetaType::Int,    3,    5,    6,    7,    8,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void,

       0        // eod
};

void TextAreaEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<TextAreaEdit *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->slotHandleTextChangedByUndoRedo((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< Okular::FormFieldText*(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5]))); break;
        case 1: _t->slotUpdateUndoAndRedoInContextMenu((*reinterpret_cast< QMenu*(*)>(_a[1]))); break;
        case 2: _t->slotChanged(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject TextAreaEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<KTextEdit::staticMetaObject>(),
    qt_meta_stringdata_TextAreaEdit.data,
    qt_meta_data_TextAreaEdit,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *TextAreaEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TextAreaEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_TextAreaEdit.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "FormWidgetIface"))
        return static_cast< FormWidgetIface*>(this);
    return KTextEdit::qt_metacast(_clname);
}

int TextAreaEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}
struct qt_meta_stringdata_FileEdit_t {
    QByteArrayData data[10];
    char stringdata0[122];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_FileEdit_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_FileEdit_t qt_meta_stringdata_FileEdit = {
    {
QT_MOC_LITERAL(0, 0, 8), // "FileEdit"
QT_MOC_LITERAL(1, 9, 11), // "slotChanged"
QT_MOC_LITERAL(2, 21, 0), // ""
QT_MOC_LITERAL(3, 22, 31), // "slotHandleFileChangedByUndoRedo"
QT_MOC_LITERAL(4, 54, 10), // "pageNumber"
QT_MOC_LITERAL(5, 65, 22), // "Okular::FormFieldText*"
QT_MOC_LITERAL(6, 88, 4), // "form"
QT_MOC_LITERAL(7, 93, 8), // "contents"
QT_MOC_LITERAL(8, 102, 9), // "cursorPos"
QT_MOC_LITERAL(9, 112, 9) // "anchorPos"

    },
    "FileEdit\0slotChanged\0\0"
    "slotHandleFileChangedByUndoRedo\0"
    "pageNumber\0Okular::FormFieldText*\0"
    "form\0contents\0cursorPos\0anchorPos"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_FileEdit[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x08 /* Private */,
       3,    5,   25,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 5, QMetaType::QString, QMetaType::Int, QMetaType::Int,    4,    6,    7,    8,    9,

       0        // eod
};

void FileEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<FileEdit *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->slotChanged(); break;
        case 1: _t->slotHandleFileChangedByUndoRedo((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< Okular::FormFieldText*(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject FileEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<KUrlRequester::staticMetaObject>(),
    qt_meta_stringdata_FileEdit.data,
    qt_meta_data_FileEdit,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *FileEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FileEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_FileEdit.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "FormWidgetIface"))
        return static_cast< FormWidgetIface*>(this);
    return KUrlRequester::qt_metacast(_clname);
}

int FileEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KUrlRequester::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
struct qt_meta_stringdata_ListEdit_t {
    QByteArrayData data[9];
    char stringdata0[131];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ListEdit_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ListEdit_t qt_meta_stringdata_ListEdit = {
    {
QT_MOC_LITERAL(0, 0, 8), // "ListEdit"
QT_MOC_LITERAL(1, 9, 20), // "slotSelectionChanged"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 35), // "slotHandleFormListChangedByUn..."
QT_MOC_LITERAL(4, 67, 10), // "pageNumber"
QT_MOC_LITERAL(5, 78, 24), // "Okular::FormFieldChoice*"
QT_MOC_LITERAL(6, 103, 8), // "listForm"
QT_MOC_LITERAL(7, 112, 10), // "QList<int>"
QT_MOC_LITERAL(8, 123, 7) // "choices"

    },
    "ListEdit\0slotSelectionChanged\0\0"
    "slotHandleFormListChangedByUndoRedo\0"
    "pageNumber\0Okular::FormFieldChoice*\0"
    "listForm\0QList<int>\0choices"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ListEdit[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x08 /* Private */,
       3,    3,   25,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 5, 0x80000000 | 7,    4,    6,    8,

       0        // eod
};

void ListEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ListEdit *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->slotSelectionChanged(); break;
        case 1: _t->slotHandleFormListChangedByUndoRedo((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< Okular::FormFieldChoice*(*)>(_a[2])),(*reinterpret_cast< const QList<int>(*)>(_a[3]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 2:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<int> >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ListEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<QListWidget::staticMetaObject>(),
    qt_meta_stringdata_ListEdit.data,
    qt_meta_data_ListEdit,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ListEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ListEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ListEdit.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "FormWidgetIface"))
        return static_cast< FormWidgetIface*>(this);
    return QListWidget::qt_metacast(_clname);
}

int ListEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QListWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
struct qt_meta_stringdata_ComboEdit_t {
    QByteArrayData data[10];
    char stringdata0[136];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ComboEdit_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ComboEdit_t qt_meta_stringdata_ComboEdit = {
    {
QT_MOC_LITERAL(0, 0, 9), // "ComboEdit"
QT_MOC_LITERAL(1, 10, 16), // "slotValueChanged"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 36), // "slotHandleFormComboChangedByU..."
QT_MOC_LITERAL(4, 65, 10), // "pageNumber"
QT_MOC_LITERAL(5, 76, 24), // "Okular::FormFieldChoice*"
QT_MOC_LITERAL(6, 101, 9), // "comboForm"
QT_MOC_LITERAL(7, 111, 4), // "text"
QT_MOC_LITERAL(8, 116, 9), // "cursorPos"
QT_MOC_LITERAL(9, 126, 9) // "anchorPos"

    },
    "ComboEdit\0slotValueChanged\0\0"
    "slotHandleFormComboChangedByUndoRedo\0"
    "pageNumber\0Okular::FormFieldChoice*\0"
    "comboForm\0text\0cursorPos\0anchorPos"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ComboEdit[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x08 /* Private */,
       3,    5,   25,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 5, QMetaType::QString, QMetaType::Int, QMetaType::Int,    4,    6,    7,    8,    9,

       0        // eod
};

void ComboEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ComboEdit *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->slotValueChanged(); break;
        case 1: _t->slotHandleFormComboChangedByUndoRedo((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< Okular::FormFieldChoice*(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ComboEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<QComboBox::staticMetaObject>(),
    qt_meta_stringdata_ComboEdit.data,
    qt_meta_data_ComboEdit,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ComboEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ComboEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ComboEdit.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "FormWidgetIface"))
        return static_cast< FormWidgetIface*>(this);
    return QComboBox::qt_metacast(_clname);
}

int ComboEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QComboBox::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
struct qt_meta_stringdata_SignatureEdit_t {
    QByteArrayData data[4];
    char stringdata0[56];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SignatureEdit_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SignatureEdit_t qt_meta_stringdata_SignatureEdit = {
    {
QT_MOC_LITERAL(0, 0, 13), // "SignatureEdit"
QT_MOC_LITERAL(1, 14, 18), // "slotViewProperties"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 21) // "signUnsignedSignature"

    },
    "SignatureEdit\0slotViewProperties\0\0"
    "signUnsignedSignature"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SignatureEdit[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x08 /* Private */,
       3,    0,   25,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void SignatureEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SignatureEdit *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->slotViewProperties(); break;
        case 1: _t->signUnsignedSignature(); break;
        default: ;
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject SignatureEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractButton::staticMetaObject>(),
    qt_meta_stringdata_SignatureEdit.data,
    qt_meta_data_SignatureEdit,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *SignatureEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SignatureEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_SignatureEdit.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "FormWidgetIface"))
        return static_cast< FormWidgetIface*>(this);
    return QAbstractButton::qt_metacast(_clname);
}

int SignatureEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractButton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
