/****************************************************************************
** Meta object code from reading C++ file 'presentationwidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../okular-23.08.5/part/presentationwidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'presentationwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_PresentationWidget_t {
    QByteArrayData data[25];
    char stringdata0[418];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PresentationWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PresentationWidget_t qt_meta_stringdata_PresentationWidget = {
    {
QT_MOC_LITERAL(0, 0, 18), // "PresentationWidget"
QT_MOC_LITERAL(1, 19, 8), // "slotFind"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 12), // "slotNextPage"
QT_MOC_LITERAL(4, 42, 12), // "slotPrevPage"
QT_MOC_LITERAL(5, 55, 13), // "slotFirstPage"
QT_MOC_LITERAL(6, 69, 12), // "slotLastPage"
QT_MOC_LITERAL(7, 82, 15), // "slotHideOverlay"
QT_MOC_LITERAL(8, 98, 18), // "slotTransitionStep"
QT_MOC_LITERAL(9, 117, 17), // "slotDelayedEvents"
QT_MOC_LITERAL(10, 135, 15), // "slotPageChanged"
QT_MOC_LITERAL(11, 151, 13), // "clearDrawings"
QT_MOC_LITERAL(12, 165, 12), // "chooseScreen"
QT_MOC_LITERAL(13, 178, 8), // "QAction*"
QT_MOC_LITERAL(14, 187, 21), // "toggleBlackScreenMode"
QT_MOC_LITERAL(15, 209, 22), // "slotProcessMovieAction"
QT_MOC_LITERAL(16, 232, 26), // "const Okular::MovieAction*"
QT_MOC_LITERAL(17, 259, 6), // "action"
QT_MOC_LITERAL(18, 266, 26), // "slotProcessRenditionAction"
QT_MOC_LITERAL(19, 293, 30), // "const Okular::RenditionAction*"
QT_MOC_LITERAL(20, 324, 19), // "slotTogglePlayPause"
QT_MOC_LITERAL(21, 344, 27), // "slotChangeDrawingToolEngine"
QT_MOC_LITERAL(22, 372, 11), // "QDomElement"
QT_MOC_LITERAL(23, 384, 7), // "element"
QT_MOC_LITERAL(24, 392, 25) // "slotAddDrawingToolActions"

    },
    "PresentationWidget\0slotFind\0\0slotNextPage\0"
    "slotPrevPage\0slotFirstPage\0slotLastPage\0"
    "slotHideOverlay\0slotTransitionStep\0"
    "slotDelayedEvents\0slotPageChanged\0"
    "clearDrawings\0chooseScreen\0QAction*\0"
    "toggleBlackScreenMode\0slotProcessMovieAction\0"
    "const Okular::MovieAction*\0action\0"
    "slotProcessRenditionAction\0"
    "const Okular::RenditionAction*\0"
    "slotTogglePlayPause\0slotChangeDrawingToolEngine\0"
    "QDomElement\0element\0slotAddDrawingToolActions"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PresentationWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   99,    2, 0x0a /* Public */,
       3,    0,  100,    2, 0x08 /* Private */,
       4,    0,  101,    2, 0x08 /* Private */,
       5,    0,  102,    2, 0x08 /* Private */,
       6,    0,  103,    2, 0x08 /* Private */,
       7,    0,  104,    2, 0x08 /* Private */,
       8,    0,  105,    2, 0x08 /* Private */,
       9,    0,  106,    2, 0x08 /* Private */,
      10,    0,  107,    2, 0x08 /* Private */,
      11,    0,  108,    2, 0x08 /* Private */,
      12,    1,  109,    2, 0x08 /* Private */,
      14,    1,  112,    2, 0x08 /* Private */,
      15,    1,  115,    2, 0x08 /* Private */,
      18,    1,  118,    2, 0x08 /* Private */,
      20,    0,  121,    2, 0x08 /* Private */,
      21,    1,  122,    2, 0x08 /* Private */,
      24,    0,  125,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 13,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, 0x80000000 | 16,   17,
    QMetaType::Void, 0x80000000 | 19,   17,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 22,   23,
    QMetaType::Void,

       0        // eod
};

void PresentationWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<PresentationWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->slotFind(); break;
        case 1: _t->slotNextPage(); break;
        case 2: _t->slotPrevPage(); break;
        case 3: _t->slotFirstPage(); break;
        case 4: _t->slotLastPage(); break;
        case 5: _t->slotHideOverlay(); break;
        case 6: _t->slotTransitionStep(); break;
        case 7: _t->slotDelayedEvents(); break;
        case 8: _t->slotPageChanged(); break;
        case 9: _t->clearDrawings(); break;
        case 10: _t->chooseScreen((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 11: _t->toggleBlackScreenMode((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->slotProcessMovieAction((*reinterpret_cast< const Okular::MovieAction*(*)>(_a[1]))); break;
        case 13: _t->slotProcessRenditionAction((*reinterpret_cast< const Okular::RenditionAction*(*)>(_a[1]))); break;
        case 14: _t->slotTogglePlayPause(); break;
        case 15: _t->slotChangeDrawingToolEngine((*reinterpret_cast< const QDomElement(*)>(_a[1]))); break;
        case 16: _t->slotAddDrawingToolActions(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject PresentationWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_PresentationWidget.data,
    qt_meta_data_PresentationWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *PresentationWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PresentationWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_PresentationWidget.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Okular::DocumentObserver"))
        return static_cast< Okular::DocumentObserver*>(this);
    return QWidget::qt_metacast(_clname);
}

int PresentationWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 17;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
