/****************************************************************************
** Meta object code from reading C++ file 'js_field_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../okular-23.08.5/core/script/js_field_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'js_field_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Okular__JSField_t {
    QByteArrayData data[15];
    char stringdata0[124];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Okular__JSField_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Okular__JSField_t qt_meta_stringdata_Okular__JSField = {
    {
QT_MOC_LITERAL(0, 0, 15), // "Okular::JSField"
QT_MOC_LITERAL(1, 16, 13), // "buttonGetIcon"
QT_MOC_LITERAL(2, 30, 8), // "QJSValue"
QT_MOC_LITERAL(3, 39, 0), // ""
QT_MOC_LITERAL(4, 40, 5), // "nFace"
QT_MOC_LITERAL(5, 46, 13), // "buttonSetIcon"
QT_MOC_LITERAL(6, 60, 5), // "oIcon"
QT_MOC_LITERAL(7, 66, 3), // "doc"
QT_MOC_LITERAL(8, 70, 4), // "name"
QT_MOC_LITERAL(9, 75, 8), // "readonly"
QT_MOC_LITERAL(10, 84, 4), // "type"
QT_MOC_LITERAL(11, 89, 5), // "value"
QT_MOC_LITERAL(12, 95, 13), // "valueAsString"
QT_MOC_LITERAL(13, 109, 6), // "hidden"
QT_MOC_LITERAL(14, 116, 7) // "display"

    },
    "Okular::JSField\0buttonGetIcon\0QJSValue\0"
    "\0nFace\0buttonSetIcon\0oIcon\0doc\0name\0"
    "readonly\0type\0value\0valueAsString\0"
    "hidden\0display"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Okular__JSField[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       8,   46, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // methods: name, argc, parameters, tag, flags
       1,    1,   34,    3, 0x02 /* Public */,
       1,    0,   37,    3, 0x22 /* Public | MethodCloned */,
       5,    2,   38,    3, 0x02 /* Public */,
       5,    1,   43,    3, 0x22 /* Public | MethodCloned */,

 // methods: parameters
    0x80000000 | 2, QMetaType::Int,    4,
    0x80000000 | 2,
    QMetaType::Void, 0x80000000 | 2, QMetaType::Int,    6,    4,
    QMetaType::Void, 0x80000000 | 2,    6,

 // properties: name, type, flags
       7, 0x80000000 | 2, 0x00095409,
       8, QMetaType::QString, 0x00095401,
       9, QMetaType::Bool, 0x00095103,
      10, QMetaType::QString, 0x00095401,
      11, 0x80000000 | 2, 0x0009510b,
      12, 0x80000000 | 2, 0x00095009,
      13, QMetaType::Bool, 0x00095103,
      14, QMetaType::Int, 0x00095103,

       0        // eod
};

void Okular::JSField::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<JSField *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { QJSValue _r = _t->buttonGetIcon((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 1: { QJSValue _r = _t->buttonGetIcon();
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->buttonSetIcon((*reinterpret_cast< const QJSValue(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 3: _t->buttonSetIcon((*reinterpret_cast< const QJSValue(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
        case 4:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<JSField *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QJSValue*>(_v) = _t->doc(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->readonly(); break;
        case 3: *reinterpret_cast< QString*>(_v) = _t->type(); break;
        case 4: *reinterpret_cast< QJSValue*>(_v) = _t->value(); break;
        case 5: *reinterpret_cast< QJSValue*>(_v) = _t->valueAsString(); break;
        case 6: *reinterpret_cast< bool*>(_v) = _t->hidden(); break;
        case 7: *reinterpret_cast< int*>(_v) = _t->display(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<JSField *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setReadonly(*reinterpret_cast< bool*>(_v)); break;
        case 4: _t->setValue(*reinterpret_cast< QJSValue*>(_v)); break;
        case 6: _t->setHidden(*reinterpret_cast< bool*>(_v)); break;
        case 7: _t->setDisplay(*reinterpret_cast< int*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Okular::JSField::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Okular__JSField.data,
    qt_meta_data_Okular__JSField,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Okular::JSField::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Okular::JSField::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Okular__JSField.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Okular::JSField::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 8;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
