/****************************************************************************
** Meta object code from reading C++ file 'js_app_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../okular-23.08.5/core/script/js_app_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'js_app_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Okular__JSApp_t {
    QByteArrayData data[34];
    char stringdata0[334];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Okular__JSApp_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Okular__JSApp_t qt_meta_stringdata_Okular__JSApp = {
    {
QT_MOC_LITERAL(0, 0, 13), // "Okular::JSApp"
QT_MOC_LITERAL(1, 14, 5), // "alert"
QT_MOC_LITERAL(2, 20, 0), // ""
QT_MOC_LITERAL(3, 21, 8), // "QJSValue"
QT_MOC_LITERAL(4, 30, 9), // "arguments"
QT_MOC_LITERAL(5, 40, 4), // "cMsg"
QT_MOC_LITERAL(6, 45, 5), // "nIcon"
QT_MOC_LITERAL(7, 51, 5), // "nType"
QT_MOC_LITERAL(8, 57, 6), // "cTitle"
QT_MOC_LITERAL(9, 64, 4), // "oDoc"
QT_MOC_LITERAL(10, 69, 9), // "oCheckbox"
QT_MOC_LITERAL(11, 79, 4), // "beep"
QT_MOC_LITERAL(12, 84, 16), // "getNthPlugInName"
QT_MOC_LITERAL(13, 101, 6), // "nIndex"
QT_MOC_LITERAL(14, 108, 6), // "goBack"
QT_MOC_LITERAL(15, 115, 9), // "goForward"
QT_MOC_LITERAL(16, 125, 11), // "setInterval"
QT_MOC_LITERAL(17, 137, 5), // "cExpr"
QT_MOC_LITERAL(18, 143, 13), // "nMilliseconds"
QT_MOC_LITERAL(19, 157, 13), // "clearInterval"
QT_MOC_LITERAL(20, 171, 9), // "oInterval"
QT_MOC_LITERAL(21, 181, 10), // "setTimeOut"
QT_MOC_LITERAL(22, 192, 12), // "clearTimeOut"
QT_MOC_LITERAL(23, 205, 5), // "oTime"
QT_MOC_LITERAL(24, 211, 12), // "formsVersion"
QT_MOC_LITERAL(25, 224, 8), // "language"
QT_MOC_LITERAL(26, 233, 10), // "numPlugIns"
QT_MOC_LITERAL(27, 244, 8), // "platform"
QT_MOC_LITERAL(28, 253, 7), // "plugIns"
QT_MOC_LITERAL(29, 261, 18), // "printColorProfiles"
QT_MOC_LITERAL(30, 280, 12), // "printerNames"
QT_MOC_LITERAL(31, 293, 10), // "viewerType"
QT_MOC_LITERAL(32, 304, 15), // "viewerVariation"
QT_MOC_LITERAL(33, 320, 13) // "viewerVersion"

    },
    "Okular::JSApp\0alert\0\0QJSValue\0arguments\0"
    "cMsg\0nIcon\0nType\0cTitle\0oDoc\0oCheckbox\0"
    "beep\0getNthPlugInName\0nIndex\0goBack\0"
    "goForward\0setInterval\0cExpr\0nMilliseconds\0"
    "clearInterval\0oInterval\0setTimeOut\0"
    "clearTimeOut\0oTime\0formsVersion\0"
    "language\0numPlugIns\0platform\0plugIns\0"
    "printColorProfiles\0printerNames\0"
    "viewerType\0viewerVariation\0viewerVersion"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Okular__JSApp[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      16,   14, // methods
      10,  170, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // methods: name, argc, parameters, tag, flags
       1,    1,   94,    2, 0x02 /* Public */,
       1,    6,   97,    2, 0x02 /* Public */,
       1,    5,  110,    2, 0x22 /* Public | MethodCloned */,
       1,    4,  121,    2, 0x22 /* Public | MethodCloned */,
       1,    3,  130,    2, 0x22 /* Public | MethodCloned */,
       1,    2,  137,    2, 0x22 /* Public | MethodCloned */,
       1,    1,  142,    2, 0x22 /* Public | MethodCloned */,
      11,    1,  145,    2, 0x02 /* Public */,
      11,    0,  148,    2, 0x22 /* Public | MethodCloned */,
      12,    1,  149,    2, 0x02 /* Public */,
      14,    0,  152,    2, 0x02 /* Public */,
      15,    0,  153,    2, 0x02 /* Public */,
      16,    2,  154,    2, 0x02 /* Public */,
      19,    1,  159,    2, 0x02 /* Public */,
      21,    2,  162,    2, 0x02 /* Public */,
      22,    1,  167,    2, 0x02 /* Public */,

 // methods: parameters
    QMetaType::Int, 0x80000000 | 3,    4,
    QMetaType::Int, QMetaType::QString, QMetaType::Int, QMetaType::Int, QMetaType::QString, 0x80000000 | 3, 0x80000000 | 3,    5,    6,    7,    8,    9,   10,
    QMetaType::Int, QMetaType::QString, QMetaType::Int, QMetaType::Int, QMetaType::QString, 0x80000000 | 3,    5,    6,    7,    8,    9,
    QMetaType::Int, QMetaType::QString, QMetaType::Int, QMetaType::Int, QMetaType::QString,    5,    6,    7,    8,
    QMetaType::Int, QMetaType::QString, QMetaType::Int, QMetaType::Int,    5,    6,    7,
    QMetaType::Int, QMetaType::QString, QMetaType::Int,    5,    6,
    QMetaType::Int, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void,
    0x80000000 | 3, QMetaType::Int,   13,
    QMetaType::Void,
    QMetaType::Void,
    0x80000000 | 3, QMetaType::QString, QMetaType::Int,   17,   18,
    QMetaType::Void, 0x80000000 | 3,   20,
    0x80000000 | 3, QMetaType::QString, QMetaType::Int,   17,   18,
    QMetaType::Void, 0x80000000 | 3,   23,

 // properties: name, type, flags
      24, QMetaType::Int, 0x00095401,
      25, QMetaType::QString, 0x00095401,
      26, QMetaType::Int, 0x00095401,
      27, QMetaType::QString, 0x00095401,
      28, 0x80000000 | 3, 0x00095409,
      29, QMetaType::QStringList, 0x00095401,
      30, QMetaType::QStringList, 0x00095401,
      31, QMetaType::QString, 0x00095401,
      32, QMetaType::QString, 0x00095401,
      33, QMetaType::Int, 0x00095401,

       0        // eod
};

void Okular::JSApp::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<JSApp *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { int _r = _t->alert((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 1: { int _r = _t->alert((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QJSValue(*)>(_a[5])),(*reinterpret_cast< const QJSValue(*)>(_a[6])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 2: { int _r = _t->alert((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QJSValue(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 3: { int _r = _t->alert((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 4: { int _r = _t->alert((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 5: { int _r = _t->alert((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 6: { int _r = _t->alert((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->beep((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->beep(); break;
        case 9: { QJSValue _r = _t->getNthPlugInName((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->goBack(); break;
        case 11: _t->goForward(); break;
        case 12: { QJSValue _r = _t->setInterval((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->clearInterval((*reinterpret_cast< const QJSValue(*)>(_a[1]))); break;
        case 14: { QJSValue _r = _t->setTimeOut((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->clearTimeOut((*reinterpret_cast< const QJSValue(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 5:
            case 4:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 4:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<JSApp *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< int*>(_v) = _t->formsVersion(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->language(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->numPlugIns(); break;
        case 3: *reinterpret_cast< QString*>(_v) = _t->platform(); break;
        case 4: *reinterpret_cast< QJSValue*>(_v) = _t->plugIns(); break;
        case 5: *reinterpret_cast< QStringList*>(_v) = _t->printColorProfiles(); break;
        case 6: *reinterpret_cast< QStringList*>(_v) = _t->printerNames(); break;
        case 7: *reinterpret_cast< QString*>(_v) = _t->viewerType(); break;
        case 8: *reinterpret_cast< QString*>(_v) = _t->viewerVariation(); break;
        case 9: *reinterpret_cast< int*>(_v) = _t->viewerVersion(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Okular::JSApp::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Okular__JSApp.data,
    qt_meta_data_Okular__JSApp,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Okular::JSApp::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Okular::JSApp::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Okular__JSApp.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Okular::JSApp::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 10;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
